function k = multiKernDiagCompute(kern, x)

% MULTIKERNDIAGCOMPUTE Compute diagonal of MULTI kernel.
%
%	Description:
%
%	K = MULTIKERNDIAGCOMPUTE(KERN, X) computes the diagonal of the
%	kernel matrix for the multiple output block kernel given a design
%	matrix of inputs.
%	 Returns:
%	  K - a vector containing the diagonal of the kernel matrix computed
%	   at the given points.
%	 Arguments:
%	  KERN - the kernel structure for which the matrix is computed.
%	  X - input data matrix in the form of a design matrix.
%	
%	
%
%	See also
%	MULTIKERNPARAMINIT, KERNDIAGCOMPUTE, KERNCREATE, MULTIKERNCOMPUTE


%	Copyright (c) 2006 Neil D. Lawrence
%	Copyright (c) 2007 Pei Gao
% 	multiKernDiagCompute.m CVS version 1.2
% 	multiKernDiagCompute.m SVN version 1
% 	last update 2007-12-19T07:05:33.000000Z

if iscell(x)
  dim = 0;
  for i = 1:length(x)
    dim = dim + length(x{i});
  end
  k = zeros(dim, 1);
  startVal = 1;
  endVal = length(x{1});
  for i = 1:length(kern.comp)
    k(startVal:endVal) = kernDiagCompute(kern.comp{i}, x{i});
    startVal = endVal + 1;
    if i+1 <= length(kern.comp)
      endVal = endVal + length(x{i+1});
    end
  end
else
  k = zeros(size(x, 1)*kern.numBlocks, 1);
  endVal = size(x, 1);
  startVal = 1;
  for i = 1:length(kern.comp)
    k(startVal:endVal, 1)  = kernDiagCompute(kern.comp{i}, x);
    startVal = endVal + 1;
    endVal = endVal + size(x, 1);
  end
end

